
# Author: 猴子
# Date: 2021-05-23 15:10:22
# LastEditTime: 2021-05-25 18:14:02
# FilePath: /code/color/__init__.py

from .color import *
from .get import *

__copyright__ = "Copyright © 2021 monkey"
__author__ = "猴子#3807"
__version__ = "0.0.9"
