from setuptools import setup

setup(
    name='monkey-color',
    version='0.0.9',
    author='monkey',
    author_email='a102009102009@gmail.com',
    url='https://github.com/a3510377/color',
    description=u'有色文字',
    packages=['color'],
    install_requires=[],
)
